pub unsafe extern "C" fn roaring64_bitmap_minimum(
r: *const roaring64_bitmap_t,
) -> u64Expand description
Returns the smallest value in the set, or UINT64_MAX if the set is empty.
pub unsafe extern "C" fn roaring64_bitmap_minimum(
r: *const roaring64_bitmap_t,
) -> u64Returns the smallest value in the set, or UINT64_MAX if the set is empty.