roaring64_bitmap_remove_bulk

Function roaring64_bitmap_remove_bulk 

pub unsafe extern "C" fn roaring64_bitmap_remove_bulk(
    r: *mut roaring64_bitmap_t,
    context: *mut roaring64_bulk_context_t,
    val: u64,
)
Remove an item, using context from a previous insert for faster removal.

context will be used to store information between calls to make bulk operations faster. *context should be zero-initialized before the first call to this function.

Modifying the bitmap in any way (other than -bulk suffixed functions) will invalidate the stored context, calling this function with a non-zero context after doing any modification invokes undefined behavior.

In order to exploit this optimization, the caller should call this function with values with the same high 48 bits of the value consecutively.