pub unsafe extern "C" fn roaring64_bitmap_remove_checked(
r: *mut roaring64_bitmap_t,
val: u64,
) -> boolExpand description
Removes a value from the bitmap if present, returns true if the value was removed and false if the value was not present.