pub unsafe extern "C" fn roaring64_iterator_read(
it: *mut roaring64_iterator_t,
buf: *mut u64,
count: u64,
) -> u64Expand description
Reads up to count values from the iterator into the given buf. Returns
the number of elements read. The number of elements read can be smaller than
count, which means that there are no more elements in the bitmap.
This function can be used together with other iterator functions.