pub unsafe extern "C" fn roaring64_iterator_read_backward(
it: *mut roaring64_iterator_t,
buf: *mut u64,
count: u64,
) -> u64Expand description
Reads previous ${count} values from iterator into user-supplied ${buf}. Returns the number of read elements. This number can be smaller than ${count}, which means that iterator is drained.
Values are written in descending order: buf[0] is the highest (current) value, buf[ret-1] is the lowest value read.
This function satisfies semantics of reverse iteration and can be used together with other iterator functions.
- first value is copied from the current iterator value
- after function returns, iterator is positioned at the previous element