pub unsafe extern "C" fn roaring_bitmap_maximum(
r: *const roaring_bitmap_t,
) -> u32Expand description
Returns the greatest value in the set, or 0 if the set is empty.
pub unsafe extern "C" fn roaring_bitmap_maximum(
r: *const roaring_bitmap_t,
) -> u32Returns the greatest value in the set, or 0 if the set is empty.