pub unsafe extern "C" fn roaring_bitmap_minimum(
r: *const roaring_bitmap_t,
) -> u32Expand description
Returns the smallest value in the set, or UINT32_MAX if the set is empty.
pub unsafe extern "C" fn roaring_bitmap_minimum(
r: *const roaring_bitmap_t,
) -> u32Returns the smallest value in the set, or UINT32_MAX if the set is empty.