pub unsafe extern "C" fn roaring_bitmap_range_uint32_array(
r: *const roaring_bitmap_t,
offset: usize,
limit: usize,
ans: *mut u32,
) -> boolExpand description
Convert the bitmap to a sorted array from offset by limit, output in
ans.
Caller is responsible to ensure that there is enough memory allocated, e.g.
ans = malloc(roaring_bitmap_get_cardinality(limit) * sizeof(uint32_t));This function always returns true
For more control, see roaring_uint32_iterator_skip and
roaring_uint32_iterator_read, which can be used to e.g. tell how many
values were actually read.