pub unsafe extern "C" fn roaring_bitmap_remove_checked(
r: *mut roaring_bitmap_t,
x: u32,
) -> boolExpand description
Remove value x Returns true if a new value was removed, false if the value was not existing.
pub unsafe extern "C" fn roaring_bitmap_remove_checked(
r: *mut roaring_bitmap_t,
x: u32,
) -> boolRemove value x Returns true if a new value was removed, false if the value was not existing.