pub unsafe extern "C" fn roaring_bitmap_remove_run_compression(
r: *mut roaring_bitmap_t,
) -> boolExpand description
Remove run-length encoding even when it is more space efficient. Return whether a change was applied.
pub unsafe extern "C" fn roaring_bitmap_remove_run_compression(
r: *mut roaring_bitmap_t,
) -> boolRemove run-length encoding even when it is more space efficient. Return whether a change was applied.