pub unsafe extern "C" fn roaring_bitmap_run_optimize(
r: *mut roaring_bitmap_t,
) -> boolExpand description
Convert array and bitmap containers to run containers when it is more efficient; also convert from run containers when more space efficient.
Returns true if the result has at least one run container.
Additional savings might be possible by calling shrinkToFit().