pub unsafe extern "C" fn roaring_iterator_create(
r: *const roaring_bitmap_t,
) -> *mut roaring_uint32_iterator_tExpand description
Create an iterator object that can be used to iterate through the values.
Caller is responsible for calling roaring_free_iterator().
The iterator is initialized (this function calls roaring_iterator_init())
If there is a value, then this iterator points to the first value and
it->has_value is true. The value is in it->current_value.