pub unsafe extern "C" fn roaring_iterator_init(
r: *const roaring_bitmap_t,
newit: *mut roaring_uint32_iterator_t,
)Expand description
Initialize an iterator object that can be used to iterate through the values.
If there is a value, then this iterator points to the first value and
it->has_value is true. The value is in it->current_value.