roaring_uint32_iterator_read_backward

Function roaring_uint32_iterator_read_backward 

pub unsafe extern "C" fn roaring_uint32_iterator_read_backward(
    it: *mut roaring_uint32_iterator_t,
    buf: *mut u32,
    count: u32,
) -> u32
Reads previous ${count} values from iterator into user-supplied ${buf}. Returns the number of read elements. This number can be smaller than ${count}, which means that iterator is drained.

Values are written in descending order: buf[0] is the highest (current) value, buf[ret-1] is the lowest value read.

This function satisfies semantics of reverse iteration and can be used together with other iterator functions.

  • first value is copied from ${it}->current_value
  • after function returns, iterator is positioned at the previous element