Struct croaring_sys::roaring_uint32_iterator_s
source · [−]#[repr(C)]pub struct roaring_uint32_iterator_s {
pub parent: *const roaring_bitmap_t,
pub container_index: i32,
pub in_container_index: i32,
pub run_index: i32,
pub current_value: u32,
pub has_value: bool,
pub container: *const c_void,
pub typecode: u8,
pub highbits: u32,
}Expand description
What follows is code use to iterate through values in a roaring bitmap
roaring_bitmap_t *r =… roaring_uint32_iterator_t i; roaring_create_iterator(r, &i); while(i.has_value) { printf(“value = %d\n”, i.current_value); roaring_advance_uint32_iterator(&i); }
Obviously, if you modify the underlying bitmap, the iterator becomes invalid. So don’t.
Fields
parent: *const roaring_bitmap_tcontainer_index: i32in_container_index: i32run_index: i32current_value: u32has_value: boolcontainer: *const c_voidtypecode: u8highbits: u32Trait Implementations
sourceimpl Clone for roaring_uint32_iterator_s
impl Clone for roaring_uint32_iterator_s
sourcefn clone(&self) -> roaring_uint32_iterator_s
fn clone(&self) -> roaring_uint32_iterator_s
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for roaring_uint32_iterator_s
impl Debug for roaring_uint32_iterator_s
impl Copy for roaring_uint32_iterator_s