roaring64_bitmap_add_offset_signed

Function roaring64_bitmap_add_offset_signed 

pub unsafe extern "C" fn roaring64_bitmap_add_offset_signed(
    r: *const roaring64_bitmap_t,
    positive: bool,
    offset: u64,
) -> *mut roaring64_bitmap_t
Return a copy of the bitmap with all values shifted by offset.

If positive is true, the shift is added, otherwise subtracted. Values that overflow or underflow uint64_t are dropped. The caller is responsible for freeing the returned bitmap.