pub unsafe extern "C" fn roaring64_bitmap_overwrite(
dest: *mut roaring64_bitmap_t,
src: *const roaring64_bitmap_t,
)Expand description
Copies a bitmap from src to dest. It is assumed that the pointer dest is to an already allocated bitmap. The content of the dest bitmap is freed/deleted.
It might be preferable and simpler to call roaring64_bitmap_copy except that roaring64_bitmap_overwrite can save on memory allocations.