pub unsafe extern "C" fn roaring_bitmap_range_uint32_array(
r: *const roaring_bitmap_t,
offset: usize,
limit: usize,
ans: *mut u32,
) -> boolExpand description
Convert the bitmap to a sorted array from offset by limit, output in
ans.
Caller is responsible to ensure that there is enough memory allocated, e.g.
ans = malloc(roaring_bitmap_get_cardinality(limit) * sizeof(uint32_t));Return false in case of failure (e.g., insufficient memory)